/*
 * @(#)ContentHandlerFactory.java	1.3 97/01/25
 *
 * (c) Copyright Sun Microsystems Inc, 1992-1999. All rights reserved.
 * (c) Copyright IBM Corporation, 1996-1999. All rights reserved.
 * 
 * This product is based in part on the work of the Independent JPEG group.
 * 
 * The Java(tm) technology is owned and exclusively licensed by 
 * Sun Microsystems Inc.  Java is a trademark of Sun Microsystems Inc. in
 * the U.S. and other countries.
 * 
 * US Govt Users Restricted Rights - Use duplication or disclosure 
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

package java.net;

/**
 * This interface defines a factory for content handlers. An 
 * implementation of this interface should map a MIME type into an 
 * instance of <code>ContentHandler</code>. 
 * <p>
 * This interface is used by the <code>URLStreamHandler</code> class 
 * to create a <code>ContentHandler</code> for a MIME type. 
 *
 * @author  James Gosling
 * @version 1.3, 01/25/97
 * @see     java.net.ContentHandler
 * @see     java.net.URLStreamHandler
 * @since   JDK1.0
 */
public interface ContentHandlerFactory {
    /**
     * Creates a new <code>ContentHandler</code> to read an object from 
     * a <code>URLStreamHandler</code>. 
     *
     * @param   mimetype   the MIME type for which a content handler is desired.

     * @return  a new <code>ContentHandler</code> to read an object from a
     *          <code>URLStreamHandler</code>.
     * @see     java.net.ContentHandler
     * @see     java.net.URLStreamHandler
     * @since   JDK1.0
     */
    ContentHandler createContentHandler(String mimetype);
}
