/*
 * @(#)PlainDatagramSocketImpl.java	1.9 97/01/21
 *
 * (c) Copyright Sun Microsystems Inc, 1992-1999. All rights reserved.
 * (c) Copyright IBM Corporation, 1996-1999. All rights reserved.
 * 
 * This product is based in part on the work of the Independent JPEG group.
 * 
 * The Java(tm) technology is owned and exclusively licensed by 
 * Sun Microsystems Inc.  Java is a trademark of Sun Microsystems Inc. in
 * the U.S. and other countries.
 * 
 * US Govt Users Restricted Rights - Use duplication or disclosure 
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

package java.net;

import java.io.FileDescriptor;
import java.io.IOException;
import java.io.InterruptedIOException;

/**
 * Concrete datagram and multicast socket implementation base class.
 * Note: This is not a public class, so that applets cannot call
 * into the implementation directly and hence cannot bypass the
 * security checks present in the DatagramSocket and MulticastSocket 
 * classes.
 *
 * @author Pavani Diwanji
 */

class PlainDatagramSocketImpl extends DatagramSocketImpl
{

    /* timeout value for receive() */
    private int timeout = 0;
    private String timeoutmode; 	// ibm.6294 Use of SO_RCVTIMEO: on-off

    /**
     * Load net library into runtime.
     */
    static {
	System.loadLibrary("net");
    }

    /**
     * Creates a datagram socket
     */
    protected synchronized void create() throws SocketException {
	fd = new FileDescriptor();
	datagramSocketCreate();
    }

    /**
     * Binds a datagram socket to a local port.
     */
    protected synchronized native void bind(int lport, InetAddress laddr) throws SocketException;

    /**
     * Sends a datagram packet. The packet contains the data and the
     * destination address to send the packet to.
     * @param packet to be sent.
     */
    protected native void send(DatagramPacket p) throws IOException;

    /**
     * Peek at the packet to see who it is from.
     * @param return the address which the packet came from.
     */
    protected synchronized native int peek(InetAddress i) throws IOException;

    /**
     * Receive the datagram packet.
     * @param Packet Received.
     */
    protected synchronized native void receive(DatagramPacket p) throws IOException;

    /**
     * Set the TTL (time-to-live) option.
     * @param TTL to be set.
     */
    protected native void setTTL(byte ttl) throws IOException;

    /**
     * Get the TTL (time-to-live) option.
     */
    protected native byte getTTL() throws IOException;

    /**
     * Join the multicast group.
     * @param multicast address to join.
     */
    protected native void join(InetAddress inetaddr) throws IOException;

    /**
     * Leave the multicast group.
     * @param multicast address to leave.
     */
    protected native void leave(InetAddress inetaddr) throws IOException;

    /**
     * Close the socket.
     */
    protected void close() {
	if (fd != null) {
	    datagramSocketClose();
	    fd = null;
	}
    }

    protected void finalize() {			/* IBM 6012 */
	close();
    }

    /**
     * set a value - since we only support (setting) binary options 
     * here, o must be a Boolean
     */

     public void setOption(int optID, Object o) throws SocketException {
	 switch (optID) {
	    /* check type safety b4 going native.  These should never
	     * fail, since only java.Socket* has access to 
	     * PlainSocketImpl.setOption().
	     */
	case SO_TIMEOUT:
	if (o == null || !(o instanceof Integer)) {
	    throw new SocketException("bad argument for SO_TIMEOUT");
	    }
	    int tmp = ((Integer) o).intValue();
	    if (tmp < 0) 
		throw new IllegalArgumentException("timeout < 0");

  	    timeoutmode = System.getProperty ("aix.timeout");	/*ibm.6294*/
	    if (timeoutmode != null && (timeoutmode.equals("on") || timeoutmode.equals("ON"))) {						/*ibm.6294*/
                try {                                           /*ibm.6294*/
                    socketSetOption(SO_TIMEOUT, o);             /*ibm.6294*/
                    timeout = 0;                                /*ibm.6294*/
                }                                               /*ibm.6294*/
                catch ( SocketException e ) {                   /*ibm.6294*/
                    timeout = tmp;                              /*ibm.6294*/
                    try {                                       /*ibm.6294*/
                        socketSetOption(SO_TIMEOUT, new Integer(0)); /*ibm.6294*/
                    }                                           /*ibm.6294*/
                     catch (SocketException f ) {               /*ibm.6294*/
		    }
                }                                               /*ibm.6294*/
            }
	    else
		timeout = tmp;                                  /*ibm.6294*/
	    return;
	 case SO_BINDADDR:
	     throw new SocketException("Cannot re-bind Socket");
	 case SO_REUSEADDR:
	     if (o == null || !(o instanceof Integer)) {
		 throw new SocketException("bad argument for SO_REUSEADDR");
	     } 
	     break;
	 case IP_MULTICAST_IF: 
	     if (o == null || !(o instanceof InetAddress))
		 throw new SocketException("bad argument for IP_MULTICAST_IF");
	     break;
	 default:
	     throw new SocketException("invalid option: " + optID);
	 }
	 socketSetOption(optID, o);
     }

    /*
     * get option's state - set or not
     */

    public Object getOption(int optID) throws SocketException {
        int ret;                                         /*ibm.6294*/
        try {                                            /*ibm.6294*/
            ret = socketGetOption(optID);                /*ibm.6294*/
        }                                                /*ibm.6294*/
        catch (SocketException e)                        /*ibm.6294*/
        {                                                /*ibm.6294*/
          if (optID==SO_TIMEOUT)                         /*ibm.6294*/
              return (Object)(new Integer(timeout));     /*ibm.6294*/
          throw e;                                       /*ibm.6294*/
        }                                                /*ibm.6294*/

	if (optID == SO_BINDADDR || optID == IP_MULTICAST_IF) {
	    InetAddress in = new InetAddress();
	    in.address = ret;
	    return in;
	}						/*ibm.6294*/
        else if (optID == SO_TIMEOUT) {                 /*ibm.6294*/
             if ((timeout == 0)&&(ret>=0))              /*ibm.6294*/
             {                                          /*ibm.6294*/
                 return (Object)(new Integer(ret));     /*ibm.6294*/
             }                                          /*ibm.6294*/
             else                                       /*ibm.6294*/
             {                                          /*ibm.6294*/
                 return (Object)(new Integer(timeout)); /*ibm.6294*/
             }                                          /*ibm.6294*/
	} else {
	    return null;
	}
    }
	
    private native void datagramSocketCreate() throws SocketException;
    private native void datagramSocketClose();
    private native void socketSetOption(int opt, Object val) throws SocketException;
    private native int socketGetOption(int opt) throws SocketException;
    
}

