/*
 * @(#)LoaderHandler.java	1.4 97/02/11
 *
 * (c) Copyright Sun Microsystems Inc, 1992-1999. All rights reserved.
 * (c) Copyright IBM Corporation, 1996-1999. All rights reserved.
 * 
 * This product is based in part on the work of the Independent JPEG group.
 * 
 * The Java(tm) technology is owned and exclusively licensed by 
 * Sun Microsystems Inc.  Java is a trademark of Sun Microsystems Inc. in
 * the U.S. and other countries.
 * 
 * US Govt Users Restricted Rights - Use duplication or disclosure 
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

package java.rmi.server;

import java.net.MalformedURLException;
import java.net.URL;

public interface LoaderHandler {
    /**
     * Find loader handler package prefix: assumes that the implementation of
     * the LoaderHandler class is located in the package defined by the
     * prefix.
     */
    final static String packagePrefix =
    System.getProperty("java.rmi.loader.packagePrefix", "sun.rmi.server");

    /**
     * Load class using java.rmi.server.codebase property.
     *
     * @exception java.lang.ClassNotFoundException if the class could not be
     *              found.
     * @exception java.net.MalformedURLException   if the URL is malformed.
     */
    Class loadClass(String name)
	throws MalformedURLException, ClassNotFoundException;

    /**
     * Load class from codebase URL specified.
     *
     * @exception java.lang.ClassNotFoundException if the class could not be
     *              found.
     * @exception java.net.MalformedURLException   if the URL is malformed.
     */
    Class loadClass(URL codebase, String name)
	throws MalformedURLException, ClassNotFoundException;

    /**
     * Returns the security context of the given class loader
     * (e.g., a URL)
     */
    Object getSecurityContext(ClassLoader loader);
    
}
