/*
 * @(#)RMIClassLoader.java
 *
 * (c) Copyright Sun Microsystems Inc, 1992-1999. All rights reserved.
 * (c) Copyright IBM Corporation, 1996-1999. All rights reserved.
 * 
 * This product is based in part on the work of the Independent JPEG group.
 * 
 * The Java(tm) technology is owned and exclusively licensed by 
 * Sun Microsystems Inc.  Java is a trademark of Sun Microsystems Inc. in
 * the U.S. and other countries.
 * 
 * US Govt Users Restricted Rights - Use duplication or disclosure 
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 */
 
/*
 * @(#)RMIClassLoader.java	1.10 97/01/06
 * 
 * Copyright (c) 1995, 1996 Sun Microsystems, Inc. All Rights Reserved.
 * 
 */

package java.rmi.server;

import java.net.MalformedURLException;
import java.net.URL;

/**
 * The RMIClassLoader class provides static methods for loading classes
 * over the network.  Classes can be loaded from either a particular URL,
 * or from the URL specified in the <b>java.rmi.server.codebase</b>
 * system property.
 * 
 * @version	1.10, 01/06/97
 * @author Ann Wollrath
 */
public class RMIClassLoader {
 
    private static final String copyr = 
        "Licensed Materials - Property of IBM\n" +
        "IBM Developer Kit, Java(TM) Tech Edition\n" +
        "(c) Copyright IBM Corp. 1996, 1999. All rights reserved.\n" +
        "\n" +
        "US Government Users Restricted Rights - Use,\n" +
        "duplication or disclosure restricted by GSA\n" +
        "ADP Schedule Contract with IBM Corp.\n" ;
 
    /*
     * Disallow anyone from creating one of these.
     */
    private RMIClassLoader() {}

    private static LoaderHandler handler = null;

    private static synchronized LoaderHandler getHandler() 
    {
	if (handler == null) {
	    try {
		Class cl = Class.forName(LoaderHandler.packagePrefix +
					 ".LoaderHandler");
		handler = (LoaderHandler)cl.newInstance();
	    } catch (Exception e) {
		throw new Error("No LoaderHandler present: " + e); /*ibm.8597*/
	    }
	}
	return handler;
    }

    /**
     * Load a class from the URL specified in the
     * <b>java.rmi.server.codebase</b> property.
     * @param name  the name of the class to load
     * @return the Class object representing the loaded class
     * @exception MalformedURLException
     *            The system property <b>java.rmi.server.codebase</b>
     *            does not contain a valid URL.
     * @exception ClassNotFoundException
     *            A definition for the class could not
     *            be found at the codebase URL.
     */
    public static Class loadClass(String name)
	throws MalformedURLException, ClassNotFoundException
    {
	return getHandler().loadClass(name);
    }
    
    /**
     * Load a class from a URL.
     * @param codebase  the URL from which to load the class
     * @param name      the name of the class to load
     * @return the Class object representing the loaded class
     * @exception MalformedURLException
     *            The codebase paramater was null.
     * @exception ClassNotFoundException
     *            A definition for the class could not
     *            be found at the specified URL.
     */
    public static Class loadClass(URL codebase, String name)
	throws MalformedURLException, ClassNotFoundException
    {
	return getHandler().loadClass(codebase, name);
    }

    /**
     * Returns the security context of the given class loader
     * @param loader a class loader from which to get the security
     * 	      context
     * @return the security context (e.g., a URL)
     */
    public static Object getSecurityContext(ClassLoader loader)
    {
	return getHandler().getSecurityContext(loader);
    }
}
