/*
 * @(#)RemoteServer.java
 *
 * (c) Copyright Sun Microsystems Inc, 1992-1999. All rights reserved.
 * (c) Copyright IBM Corporation, 1996-1999. All rights reserved.
 * 
 * This product is based in part on the work of the Independent JPEG group.
 * 
 * The Java(tm) technology is owned and exclusively licensed by 
 * Sun Microsystems Inc.  Java is a trademark of Sun Microsystems Inc. in
 * the U.S. and other countries.
 * 
 * US Govt Users Restricted Rights - Use duplication or disclosure 
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 */
 
/*
 * @(#)RemoteServer.java	1.10 98/08/12
 *
 * Copyright 1995-1998 by Sun Microsystems, Inc.,
 * 901 San Antonio Road, Palo Alto, California, 94303, U.S.A.
 * All rights reserved.
 * 
 */
package java.rmi.server;

import java.rmi.*;

/**
 * The RemoteServer class is the common superclass to all server
 * implementations and provides the framework to support a wide range
 * of remote reference semantics.  Specifically, the functions needed
 * to create and export remote objects (i.e. to make them remotely
 * available) are provided abstractly by RemoteServer and concretely
 * by its subclass(es). <p>
 *
 * The subclass selected identifies the semantics of the remote
 * reference, for example whether the server is a single object or is
 * a replicated object requiring communications with multiple
 * locations. At present only UnicastRemoteObject is supported.
 */
public abstract class RemoteServer extends RemoteObject
{
 
    private static final String copyr = 
        "Licensed Materials - Property of IBM\n" +
        "IBM Developer Kit, Java(TM) Tech Edition\n" +
        "(c) Copyright IBM Corp. 1996, 1999. All rights reserved.\n" +
        "\n" +
        "US Government Users Restricted Rights - Use,\n" +
        "duplication or disclosure restricted by GSA\n" +
        "ADP Schedule Contract with IBM Corp.\n" ;
 
    private static final long serialVersionUID = -4100238210092549637L;

    private static String logname = "RMI";
    private static LogStream log;

    protected RemoteServer() {
	super();
    }
    
    protected RemoteServer(RemoteRef ref) {
	super(ref);
    }

    /**
     * Return the hostname of the current client.  When called from a
     * thread actively handling a remote method invocation the
     * hostname of the client is returned.
     * @exception ServerNotActiveException If called outside of servicing
     * a remote method invocation.
     */
    public static String getClientHost() throws ServerNotActiveException {
	try {
	    Class refClass = Class.forName(RemoteRef.packagePrefix +
					   ".UnicastServerRef");
	    ServerRef ref = (ServerRef)refClass.newInstance();
	    return ref.getClientHost();
	} catch (ServerNotActiveException e) {
	    throw e;
	} catch (Exception e) {
	    throw new ServerNotActiveException("Client host unobtainable: " + e); /*ibm.8597*/
	}
    }

    /**
     * Log RMI calls to the output stream <I>out</I>. If <I>out</I> is
     * null, call logging is turned off.
     */
    public static void setLog(java.io.OutputStream out) 
    {
	if (out == null) {
	    log = null;
	} else {
	    LogStream tempLog = LogStream.log(logname);
	    tempLog.setOutputStream(out);
	    log = tempLog;
	}
    }
    /**
     * Returns stream for the RMI call log.
     */
    public static java.io.PrintStream getLog() 
    {
	return log;
    }

    static 
    {
	// initialize log
	try {
	    log = (Boolean.getBoolean("java.rmi.server.logCalls") ?
		   LogStream.log(logname) : null);
	} catch (Exception e) {
	}
    }
}
