/*
 * @(#)DateFormatZoneData.java	1.6 97/10/28
 *
 * (c) Copyright Sun Microsystems Inc, 1992-1999. All rights reserved.
 * (c) Copyright IBM Corporation, 1996-1999. All rights reserved.
 * 
 * This product is based in part on the work of the Independent JPEG group.
 * 
 * The Java(tm) technology is owned and exclusively licensed by 
 * Sun Microsystems Inc.  Java is a trademark of Sun Microsystems Inc. in
 * the U.S. and other countries.
 * 
 * US Govt Users Restricted Rights - Use duplication or disclosure 
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

package java.text.resources;

import java.util.ListResourceBundle;

/**
 * Supplement package private date-time formatting zone data for DateFormat.
 * DateFormatData used in DateFormat will be initialized by loading the data
 * from LocaleElements and DateFormatZoneData resources. The zone data are
 * represented with the following form:
 * {ID, long zone string, short zone string, long daylight string,
 * short daylight string, representative city of zone}, where ID is
 * NOT localized, but is used to look up the localized timezone data
 * internally. Localizers can localize any zone strings except
 * for the ID of the timezone.

 * @see          ListResourceBundle
 * @see          Format
 * @see          DateFormatData
 * @see          LocaleElements
 * @see          SimpleDateFormat
 * @see          TimeZone
 * @version      1.6 10/28/97
 * @author       Chen-Lieh Huang
 */
//  US DateFormatZoneData
//
public final class DateFormatZoneData extends ListResourceBundle
{
    /**
     * Overrides ListResourceBundle
     */
    public Object[][] getContents() {
        return contents;
    }

    private static final String kZoneStrings[][] = {
        {"PST", "Pacific Standard Time", "PST",
        "Pacific Daylight Time", "PDT", "San Francisco"},
        {"MST", "Mountain Standard Time", "MST",
        "Mountain Daylight Time", "MDT", "Denver"},
        {"PNT", "Mountain Standard Time", "MST",
        "Mountain Standard Time", "MST", "Phoenix"},
        {"CST", "Central Standard Time", "CST",
        "Central Daylight Time", "CDT", "Chicago"},
        {"EST", "Eastern Standard Time", "EST",
        "Eastern Daylight Time", "EDT", "New York"},
        // IET is the ID for Indiana Eastern Standard Time timezone.
        {"IET", "Eastern Standard Time", "EST",
        "Eastern Standard Time", "EST", "Indianapolis"},
        // PRT is the ID for Puerto Rico and US Virgin Islands Time timezone.
        {"PRT", "Atlantic Standard Time", "AST",
        "Atlantic Daylight Time", "ADT", "Halifax"},
        {"HST", "Hawaii Standard Time", "HST",
        "Hawaii Daylight Time", "HDT", "Honolulu"},
        {"AST", "Alaska Standard Time", "AST",
        "Alaska Daylight Time", "ADT", "Anchorage"}
    };

    private static final String kLocalPatternChars = "GyMdkHmsSEDFwWahKz";

    static final Object[][] contents = {
        {"zoneStrings",         kZoneStrings},
        {"localPatternChars",   kLocalPatternChars},
    };
}
