/*
 * @(#)DateFormatZoneData_ja.java	1.6 98/03/05
 *
 * (c) Copyright Sun Microsystems Inc, 1992-1999. All rights reserved.
 * (c) Copyright IBM Corporation, 1996-1999. All rights reserved.
 * 
 * This product is based in part on the work of the Independent JPEG group.
 * 
 * The Java(tm) technology is owned and exclusively licensed by 
 * Sun Microsystems Inc.  Java is a trademark of Sun Microsystems Inc. in
 * the U.S. and other countries.
 * 
 * US Govt Users Restricted Rights - Use duplication or disclosure 
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 */

package java.text.resources;

import java.util.ListResourceBundle;

/**
 * Supplement package private date-time formatting zone data for DateFormat.
 * DateFormatData used in DateFormat will be initialized by loading the data
 * from LocaleElements and DateFormatZoneData resources. The zone data are
 * represented with the following form:
 * {ID, long zone string, short zone string, long daylight string,
 * short daylight string, representative city of zone}, where ID is
 * NOT localized, but is used to look up the localized timezone data
 * internally. Localizers can localize any zone strings except
 * for the ID of the timezone.

 * @see          ListResourceBundle
 * @see          Format
 * @see          DateFormatData
 * @see          LocaleElements
 * @see          SimpleDateFormat
 * @see          TimeZone
 * @version      1.6 03/05/98
 * @author       Chen-Lieh Huang
 */
//  Japan DateFormatZoneData
//
public final class DateFormatZoneData_ja extends ListResourceBundle
{
    /**
     * Overrides ListResourceBundle
     */
    public Object[][] getContents() {
        return contents;
    }

    private static final String kZoneStrings[][] = {
        // The first row below is the default TimeZone for this locale.
        // Zones should have unique names and abbreviations within
        // this locale.  Names and abbreviations may be identical
        // if the corresponding zones really are identical.  E.g.:
        // America/Phoenix and America/Denver both use MST; these
        // zones differ only in that America/Denver uses MDT as well.
        {
            "Asia/Tokyo", "\u65e5\u672c\u6a19\u6e96\u6642", "JST",
            "\u65e5\u672c\u6a19\u6e96\u6642", "JST"
        }
    };

    private static final String kLocalPatternChars = "GanjkHmsSEDFwWxhKz";

    static final Object[][] contents = {
        {"zoneStrings",         kZoneStrings},
        {"localPatternChars",   kLocalPatternChars},
    };
}
